@@ -16,11 +16,8 @@ class AnnouncementUpdateForm(PartialUpdateMixin, forms.ModelForm):
     text = forms.CharField(label=_("Description"),
                            max_length=150,
                            help_text="Maximaal 150 karakters",
-                           widget=forms.Textarea(
-            attrs={'class': 'full wysiwyg',
-                   'data-maxchars': 150,
-                   'rows': '5'})
-                             )
+                           widget=forms.Textarea()
+                           )
 
     @property
     def labels(self):
